California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 62 - ELECTIONS. PRIMARIES. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1267905 | NO ON 62 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1267433 | COMMITTEE FOR AN INDEPENDENT VOICE & INDEPENDENT VOTERS FOR AN OPEN PRIMARY, YES ON 62 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1260238 | CALIFORNIANS FOR AN OPEN PRIMARY PAC, YES ON 62, NO ON 60, MAJOR FUNDING BY AGRICULTURE, TECHNOLOGY, LAND, FINANCIAL INSTITUTIONS, INSURANCE, EDUCATOR, TRUSTS, BUSINESSPERSONS/PHILANTHROPISTS, STEVEN | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1266426 | CALIFORNIANS FOR ELECTION ACCOUTABILITY, NO ON 62 | OPPOSE